% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RMS.R
\name{RMS}
\alias{RMS}
\title{Compute root mean square error}
\usage{
RMS(exp, obs, time_dim = "sdate", memb_dim = "member", comp_dim = NULL,
  limits = NULL, conf = TRUE, conf.lev = 0.95, ncores = NULL)
}
\arguments{
\item{exp}{A named numeric array of experimental data, with at least two 
dimensions 'time_dim' and 'memb_dim'.}

\item{obs}{A named numeric array of observational data, same dimensions as
parameter 'exp' except along memb_dim.}

\item{time_dim}{A character string indicating the name of dimension along
which the correlations are computed. The default value is 'sdate'.}

\item{memb_dim}{A character string indicating the name of member (nobs/nexp) 
dimension. The default value is 'member'.}

\item{comp_dim}{A character string indicating the name of dimension along which
the data is taken into account only if it is complete. The default value
is NULL.}

\item{limits}{A vector of two integers indicating the range along comp_dim to 
be completed. The default value is c(1, length(comp_dim dimension)).}

\item{conf}{A logical value indicating whether to retrieve the confidence 
intervals or not. The default value is TRUE.}

\item{conf.lev}{A numeric indicating the confidence level for the 
regression computation. The default value is 0.95.}

\item{ncores}{An integer indicating the number of cores to use for parallel 
computation. The default value is NULL.}
}
\value{
A list containing the numeric arrays with dimension:\cr 
 c(nexp, nobs, all other dimensions of exp except time_dim).\cr
nexp is the number of experiment (i.e., memb_dim in exp), and nobs is the 
number of observation (i.e., memb_dim in obs).\cr
\item{$rms}{
 The root mean square error. 
}
\item{$conf.lower}{
 The lower confidence interval. Only present if \code{conf = TRUE}.
}
\item{$conf.upper}{
 The upper confidence interval. Only present if \code{conf = TRUE}.
}
}
\description{
Compute the root mean square error for an array of forecasts and an array of
observations. The RMSEs are computed along time_dim, the dimension which 
corresponds to the startdate dimension. If comp_dim is given, the RMSEs are 
computed only if data along the comp_dim dimension are complete between 
limits[1] and limits[2], i.e. there are no NAs between limits[1] and 
limits[2]. This option can be activated if the user wishes to account only 
for the forecasts for which the corresponding observations are available at 
all leadtimes.\cr
The confidence interval is computed by the chi2 distribution.\cr
}
\examples{
# Load sample data as in Load() example:
example(Load)
clim <- Clim(sampleData$mod, sampleData$obs)
ano_exp <- Ano(sampleData$mod, clim$clim_exp)
ano_obs <- Ano(sampleData$obs, clim$clim_obs)
runmean_months <- 12
dim_to_smooth <- 4  # Smooth along lead-times
smooth_ano_exp <- Smoothing(ano_exp, runmean_months, dim_to_smooth)
smooth_ano_obs <- Smoothing(ano_obs, runmean_months, dim_to_smooth)
dim_to_mean <- 2  # Mean along members
# Discard start-dates for which some leadtimes are missing
leadtimes_per_startdate <- 60
rms <- RMS(smooth_ano_exp, 
          smooth_ano_obs, 
          comp_dim = 'ftime', 
          limits = c(ceiling((runmean_months + 1) / 2), 
                     leadtimes_per_startdate - floor(runmean_months / 2)))

}
\author{
History:\cr
0.1  -  2011-05  (V. Guemas, \email{vguemas@ic3.cat})  -  Original code\cr
1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens2@ic3.cat})  -  Formatting to R CRAN\cr
1.1  -  2017-02  (A. Hunter, \email{alasdair.hunter@bsc.es})  -  Adapted to veriApply()
3.0  -  2020-01  (A. Ho, \email{an.ho@bsc.es})  -  Adapt multiApply feature
}
\keyword{datagen}

